@@ -8,17 +8,18 @@
 
 #include "whatsnewdialog.h"
 #include <KLocalizedString>
-#include <QCoreApplication>
 
 using namespace Qt::Literals::StringLiterals;
 using namespace PimCommon;
-WhatsNewMessageWidget::WhatsNewMessageWidget(QWidget *parent)
+WhatsNewMessageWidget::WhatsNewMessageWidget(QWidget *parent, const QString &applicationName)
     : KMessageWidget(parent)
 {
     setVisible(false);
     setCloseButtonVisible(true);
     setMessageType(Information);
-    setText(i18n("What's new in %2. %1", QStringLiteral("<a href=\"show_whats_new\">%1</a>").arg(i18n("(Show News)")), QCoreApplication::applicationName()));
+
+    mApplicationName = applicationName;
+    setText(i18n("What's new in %2. %1", QStringLiteral("<a href=\"show_whats_new\">%1</a>").arg(i18n("(Show News)")), mApplicationName));
     setPosition(KMessageWidget::Header);
     connect(this, &KMessageWidget::linkActivated, this, &WhatsNewMessageWidget::slotLinkActivated);
 }
@@ -28,7 +29,7 @@ WhatsNewMessageWidget::~WhatsNewMessageWidget() = default;
 void WhatsNewMessageWidget::slotLinkActivated(const QString &contents)
 {
     if (contents == "show_whats_new"_L1) {
-        WhatsNewDialog dlg(mWhatsNewInfos, this);
+        WhatsNewDialog dlg(mWhatsNewInfos, this, mApplicationName);
         dlg.updateInformations();
         dlg.exec();
     }
